==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/DataSourceSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceSchemaChangedEventArgsDescription } from "./DataSourceSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
export let DataSourceSchemaChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceSchemaChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceSchemaChangedEventArgsDescriptionMetadata.a == null) {
                DataSourceSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceSchemaChangedEventArgsDescriptionMetadata.c(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataSourceSchemaChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            DataSourceSchemaChangedEventArgsDescriptionMetadata.b(a);
            a.ad("DataSourceSchemaChangedEventArgs", () => new DataSourceSchemaChangedEventArgsDescription());
            a.ac("DataSourceSchemaChangedEventArgs", DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
        }
    }
    DataSourceSchemaChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceSchemaChangedEventArgsDescriptionMetadata, 'DataSourceSchemaChangedEventArgsDescriptionMetadata');
    DataSourceSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceSchemaChangedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/DataSourceSchemaChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceSchemaChangedEventArgsDescription } from "./DataSourceSchemaChangedEventArgsDescription";
/**
 * @hidden
 */
export let DataSourceSchemaChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataSourceSchemaChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataSourceSchemaChangedEventArgsDescriptionMetadata.a == null) {
                DataSourceSchemaChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataSourceSchemaChangedEventArgsDescriptionMetadata.c(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataSourceSchemaChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            DataSourceSchemaChangedEventArgsDescriptionMetadata.b(a);
            a.ae("DataSourceSchemaChangedEventArgs", () => new DataSourceSchemaChangedEventArgsDescription());
            a.ad("DataSourceSchemaChangedEventArgs", DataSourceSchemaChangedEventArgsDescriptionMetadata.a);
        }
    }
    DataSourceSchemaChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataSourceSchemaChangedEventArgsDescriptionMetadata, 'DataSourceSchemaChangedEventArgsDescriptionMetadata');
    DataSourceSchemaChangedEventArgsDescriptionMetadata.a = null;
    return DataSourceSchemaChangedEventArgsDescriptionMetadata;
})();
